﻿Fluke Calibration                                           MET/CAL Procedure
=============================================================================
INSTRUMENT:            Sub Level Signal /4418,8481,SWPG
DATE:                  2012-03-28 15:55:26
AUTHOR:                Fluke
REVISION:              $Revision: 2619 $
ADJUSTMENT THRESHOLD:  70%
NUMBER OF TESTS:       1
NUMBER OF LINES:       144
CONFIGURATION:         Agilent E4418B
CONFIGURATION:         HP 8481A on channel 1
CONFIGURATION:         Sweep Generator
=============================================================================
#
# Procedure Author:
#        DFM, CAD
#
# Model(s) Covered:
#        General purpose use, wherever a leveled (RF) signal, >=50 MHz and
#        <=18 GHz, using a Sweep Generator (SWPG) is required.
#
# Compatibility:
#        MET/CAL 7.2 or later
#
# Subprocedures:
#        Sub Apply /SWPG
#        Sub Output Off /SWPG
#
# Required Files:
#        None
#
# Additional Equipment Required:
#        None
#
# The necessary parameters for this procedure are passed from the calling
# procedure.
#
# @TestName   : The test being performed when this sub is being called.
# @CenterFreq : The desired Sweep Generator output frequency.
# @RefLvl     : The desired reference level as measured by the power meter.
# @TestLvl    : The Sweep Generator output level required to generate the
#               specified reference level.
# @HiLimit    : The upper limit of the setting aperture (in dBm).
# @LoLimit    : The lower limit of the setting aperture (in dBm).
# @Error      : Flag to indicate success or failure of leveling process and
#               facilitating 'bail-out' in the case of the latter.
#
# Example:
# 1.001  M4418  F32   8481A
# 1.002  MATH         @TestName = "Frequency Response"
# 1.003  MATH         @CenterFreq = 300E+6; @RefLvl = -12; @TestLvl = -12
# 1.004  MATH         @LoLimit = -12.05; @HiLimit = -11.95
# 1.005  CALL         Sub Level Signal /4418,8481,SWPG
#
# 1.006  IF           @Error
# 1.007  EVAL   -e 0 : An error occurred during the [V @TestName] test.
# 2.001  MATH         @Error = 0
# 2.002  END
# 2.003  ENDIF
#
# The copyright for this procedure is owned by Fluke Corporation.
#
 STEP    FSC    RANGE NOMINAL        TOLERANCE     MOD1        MOD2  3  4 CON

  1.001  IF           0
# M4418 statement to allow procedure to compile.
  1.002  M4418  F32   8481A
  1.003  IEEE         [@SWPG]
  1.004  ENDIF

# Allow calling procedure to specify maximum number of iterations to use in
# this leveling routine.
  1.005  IF           ISVAR("@iMax")
  1.006  MATH         iMax = @iMax
  1.007  ELSE         ; Use default value.
  1.008  MATH         iMax = 10
  1.009  ENDIF

# Create a local backup of @TestLvl; used for Retry after @Error.
  1.010  MATH         TestLvl = @TestLvl
# Pass @RefLvl into MEM to establish starting point for power measurement.
  1.011  MATH         MEM = @RefLvl

  1.012  DO           ; Until signal is leveled or an error occurs.
  1.013  MATH         Count = 0

  1.014  DO           ; Until signal is leveled or limit is reached.
  1.015  MATH         Delta      = @RefLvl - MEM
  1.016  MATH         @TestLvl   = @TestLvl + Delta
  1.017  MATH         @SWPG_Ampl = @TestLvl & " dBm"
  1.018  CALL         Sub Apply /SWPG

# Pass center frequency (in Hz) from calling procedure to power meter FSC.
  1.019  MATH         MEM = @CenterFreq
# -25 dBm nominal value compatible with all variations of power sensors.
  1.020  4418         -25.00D                      H                 RF N  CH1

# Perform status checks.
  1.021  MATH         Leveled = (MEM >= @LoLimit) && (MEM <= @HiLimit)
  1.022  MATH         Count   = (Count + 1)
  1.023  MATH         Stop    = (Count > iMax)
  1.024  MATH         Limit   = (@TestLvl < -100) || (@TestLvl > 20)
  1.025  UNTIL        Leveled || Stop || Limit

  1.026  MATH         @Error = NOT(Leveled) && (Stop || Limit)

  1.027  IF           @Error
  1.028  CALL         Sub Output Off /SWPG
  1.029  OPBR         -z Error: Unable to adjust the Sweep Generator output
  1.029  OPBR         [32]      level within its operating range to achieve
  1.029  OPBR         [32]      the desired test level ([V @RefLvl] dBm) after
  1.029  OPBR         [32]      [V iMax] attempts.
  1.029  OPBR
  1.029  OPBR         [32]      Verify UUT test requirements, SWPG output
  1.029  OPBR         [32]      limits, and connections prior to retrying,
  1.029  OPBR         [32]      if desired.
  1.029  OPBR
  1.029  OPBR         [32]      If the generator is near an amplitude level
  1.029  OPBR         [32]      that causes an internal attenuator to be
  1.029  OPBR         [32]      switched in and out of the signal path during
  1.029  OPBR         [32]      leveling attempts, inserting or removing a pad
  1.029  OPBR         [32]      and then retrying may resolve the issue.
  1.029  OPBR
  1.029  OPBR         Do you wish to RETRY?
  1.029  OPBR
  1.029  OPBR         (Selecting "No" will cause the [V @TestName] test
  1.029  OPBR         to be terminated.)
  1.029  OPBR         [7][D250][7][D250][7][D250][7][D250][7]
  1.030  MATH         @Error = NOT(MEM1)

  1.031  IF           MEM1
# Restore original levels and start over.
  1.032  MATH         @TestLvl = TestLvl; MEM = @RefLvl
  1.033  ENDIF

  1.034  ENDIF        ; @Error

  1.035  UNTIL        Leveled || @Error

  1.036  END
